CaptureNetworkTrafficCommand.Header (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.commands
Class CaptureNetworkTrafficCommand.Header

    java.lang.Object
      org.openqa.selenium.server.commands.CaptureNetworkTrafficCommand.Header

Enclosing class:
  CaptureNetworkTrafficCommand

    public static class CaptureNetworkTrafficCommand.Header

extends java.lang.Object

Constructor Summary
`CaptureNetworkTrafficCommand.Header(java.lang.String name, java.lang.String value)`

Method Summary

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### CaptureNetworkTrafficCommand.Header

    public CaptureNetworkTrafficCommand.Header(java.lang.String name,
                                               java.lang.String value)

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.